#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (C) 2007-2008 One Laptop Per Child Association, Inc.
# Written by Ivan Krstić and C. Scott Ananian

# This program is free software; you can redistribute it and/or modify
# it under the terms of version 2 (and no other version) of the GNU
# General Public License as published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

"""Exception classes used by `bitfrost.leases.crypto` and
`bitfrost.leases.core`."""

class SecurityException(Exception):
    """Base exception for Bitfrost security token validation."""
    pass

class UnsupportedLeaseFormat(SecurityException):
    """This lease format is unsupported by the software. Please upgrade the
    machine to a more recent software build."""
    pass

class VerificationFailure(SecurityException):
    """The lease verification failed. This lease is incorrect for the
    machine in question, or damaged."""
    pass

class LeaseExpired(SecurityException):
    """This lease has expired."""
    pass

class InvalidLeaseData(SecurityException):
    """Could not interpret the lease data."""
    pass
    
class InvalidDevKeyData(SecurityException):
    """Could not interpret the developer key data."""
    pass
    
class InvalidSignatureData(SecurityException):
    """Could not interpret the signature data."""
    pass
    
class InvalidKey(SecurityException):
    """The key used for the signature is not trusted."""
    pass

class NoLeaseFound(SecurityException):
    """Can't find lease for this computer in the lease data."""
    pass
